@@ -137,7 +137,7 @@ use warnings;
 
 use base qw{Astro::Coord::ECI::TLE};
 
-our $VERSION = '0.098_02';
+our $VERSION = '0.098_03';
 
 use Astro::Coord::ECI::Sun;
 use Astro::Coord::ECI::Utils qw{:all};
@@ -1688,7 +1688,7 @@ sub _set_operational_status {
 # All Iridium Classic satellites.
 #
 # Generated by Astro::SpaceTrack tools/all_iridium_classic -tle -indent=0
-# on Thu Jun 21 13:01:02 2018 GMT
+# on Sat Jun 23 13:46:52 2018 GMT
 
 __PACKAGE__->status( clear => 'iridium' );
 __PACKAGE__->status( add => 24792, iridium => 'D', 'Iridium 8', 'Decayed 2017-11-24' );
@@ -1764,7 +1764,7 @@ __PACKAGE__->status( add => 25342, iridium => '+', 'Iridium 70', '' );
 __PACKAGE__->status( add => 25343, iridium => 'D', 'Iridium 72', 'Decayed 2018-05-14' );
 __PACKAGE__->status( add => 25344, iridium => '-', 'Iridium 73', 'Tumbling' );
 __PACKAGE__->status( add => 25345, iridium => 'D', 'Iridium 74', 'Decayed 2017-06-11' );
-__PACKAGE__->status( add => 25346, iridium => 'S', 'Iridium 75', '' );
+__PACKAGE__->status( add => 25346, iridium => '-', 'Iridium 75', 'Tumbling' );
 __PACKAGE__->status( add => 25431, iridium => 'D', 'Iridium 3', 'Decayed 2018-02-08' );
 __PACKAGE__->status( add => 25432, iridium => 'S', 'Iridium 76', '' );
 __PACKAGE__->status( add => 25467, iridium => '-', 'Iridium 82', 'Tumbling' );
@@ -1791,8 +1791,8 @@ __PACKAGE__->status( add => 27451, iridium => '+', 'Iridium 98', '' );
 
 # Summary:
 # Operational [+]: 20
-#       Spare [S]: 17
-#    Tumbling [-]: 37
+#       Spare [S]: 16
+#    Tumbling [-]: 38
 #     Decayed [D]: 23
 
 1;
